ShareData class

Data structure for sharing, containing information related to sharing mini programs or images, etc.

Constructors

ShareData({String? appId, String? appIcon, String? appTitle, String? appDescription, String? appVersion, String? path, String? title, String? query, String? imageUrl, String? shareType})
Constructor to initialize ShareData

Properties

appDescription String?
The description of the mini program
getter/setter pair
appIcon String?
The URL of the mini program icon
getter/setter pair
appId String?
The appId of the mini program
getter/setter pair
appTitle String?
The title of the mini program
getter/setter pair
appVersion String?
The version of the mini program
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
The URL of the image to share
getter/setter pair
path String?
The path to navigate to (mini program page path)
getter/setter pair
query String?
The query parameters for sharing (query string)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareType String?
The type of sharing (miniapp or picture)
getter/setter pair
title String?
The title for sharing
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) ShareData?
Create a ShareData instance from a Map
fromOCMap(Map<Object?, Object?>? map) ShareData?
Create a ShareData instance from an Objective-C style Map