ShareData class
Data structure for sharing, containing information related to sharing mini programs or images, etc.
Constructors
- Constructor to initialize ShareData
Properties
- appDescription ↔ String?
-
The description of the mini program
getter/setter pair
- appIcon ↔ String?
-
The URL of the mini program icon
getter/setter pair
- appId ↔ String?
-
The appId of the mini program
getter/setter pair
- appTitle ↔ String?
-
The title of the mini program
getter/setter pair
- appVersion ↔ String?
-
The version of the mini program
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl ↔ String?
-
The URL of the image to share
getter/setter pair
- path ↔ String?
-
The path to navigate to (mini program page path)
getter/setter pair
- query ↔ String?
-
The query parameters for sharing (query string)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
The type of sharing (miniapp or picture)
getter/setter pair
- title ↔ String?
-
The title for sharing
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited